package com.ruoyi.ems.mapper;

import java.util.List;
import java.util.Set;

import com.ruoyi.ems.domain.AreaBuildingZoning;

/**
 * 建筑区域划分Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-09
 */
public interface AreaBuildingZoningMapper {
    /**
     * 查询建筑区域划分
     *
     * @param id 建筑区域划分主键
     * @return 建筑区域划分
     */
    AreaBuildingZoning selectAreaBuildingZoningById(Long id);

    /**
     * 查询建筑区域code
     *
     * @param code 建筑区域划分主键
     * @return 建筑区域划分
     */
    AreaBuildingZoning selectAreaBuildingZoningByCode(String code);

    /**
     * 根据code集合查询
     * @param codes code集合
     * @return 建筑区域划分
     */
    List<AreaBuildingZoning> selectByCodes(Set<String> codes);

    /**
     * 查询建筑区域划分列表
     *
     * @param areaBuildingZoning 建筑区域划分
     * @return 建筑区域划分集合
     */
    List<AreaBuildingZoning> selectAreaBuildingZoningList(AreaBuildingZoning areaBuildingZoning);

    /**
     * 新增建筑区域划分
     *
     * @param areaBuildingZoning 建筑区域划分
     * @return 结果
     */
    int insertAreaBuildingZoning(AreaBuildingZoning areaBuildingZoning);

    /**
     * 修改建筑区域划分
     *
     * @param areaBuildingZoning 建筑区域划分
     * @return 结果
     */
    int updateAreaBuildingZoning(AreaBuildingZoning areaBuildingZoning);

    /**
     * 删除建筑区域划分
     *
     * @param id 建筑区域划分主键
     * @return 结果
     */
    int deleteAreaBuildingZoningById(Long id);

    /**
     * 删除建筑区域划分
     *
     * @param code 建筑code
     * @return 结果
     */
    int deleteAreaBuildingZoningByBuilding(String code);

    /**
     * 批量删除建筑区域划分
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAreaBuildingZoningByIds(Long[] ids);
}
