package com.ruoyi.ems.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AreaBuildingZoning;
import com.ruoyi.ems.service.IAreaBuildingZoningService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 建筑区域划分Controller
 * 
 * @author ruoyi
 * @date 2024-07-09
 */
@RestController
@RequestMapping("/basecfg/area/building/zoning")
@Api(value = "AreaBuildingZoningController", description = "建筑功能分区管理")
public class AreaBuildingZoningController extends BaseController
{
    @Autowired
    private IAreaBuildingZoningService areaBuildingZoningService;

    /**
     * 查询建筑区域划分列表
     */
    @RequiresPermissions("basecfg:zoning:list")
    @GetMapping("/list")
    public TableDataInfo list(AreaBuildingZoning areaBuildingZoning)
    {
        startPage();
        List<AreaBuildingZoning> list = areaBuildingZoningService.selectAreaBuildingZoningList(areaBuildingZoning);
        return getDataTable(list);
    }

    /**
     * 导出建筑区域划分列表
     */
    @RequiresPermissions("basecfg:zoning:export")
    @Log(title = "建筑区域划分", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AreaBuildingZoning areaBuildingZoning)
    {
        List<AreaBuildingZoning> list = areaBuildingZoningService.selectAreaBuildingZoningList(areaBuildingZoning);
        ExcelUtil<AreaBuildingZoning> util = new ExcelUtil<AreaBuildingZoning>(AreaBuildingZoning.class);
        util.exportExcel(response, list, "建筑区域划分数据");
    }

    /**
     * 获取建筑区域划分详细信息
     */
    @RequiresPermissions("basecfg:zoning:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(areaBuildingZoningService.selectAreaBuildingZoningById(id));
    }

    /**
     * 新增建筑区域划分
     */
    @RequiresPermissions("basecfg:zoning:add")
    @Log(title = "建筑区域划分", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AreaBuildingZoning areaBuildingZoning)
    {
        return toAjax(areaBuildingZoningService.insertAreaBuildingZoning(areaBuildingZoning));
    }

    /**
     * 修改建筑区域划分
     */
    @RequiresPermissions("basecfg:zoning:edit")
    @Log(title = "建筑区域划分", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AreaBuildingZoning areaBuildingZoning)
    {
        return toAjax(areaBuildingZoningService.updateAreaBuildingZoning(areaBuildingZoning));
    }

    /**
     * 删除建筑区域划分
     */
    @RequiresPermissions("basecfg:zoning:remove")
    @Log(title = "建筑区域划分", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(areaBuildingZoningService.deleteAreaBuildingZoningByIds(ids));
    }
}
